@@ -468,7 +468,8 @@ class _BookArea(gtk.ScrolledWindow):
             [('book', gtk.TARGET_SAME_APP, _DRAG_BOOK_ID)],
             gtk.gdk.ACTION_MOVE)
         self._iconview.drag_dest_set(gtk.DEST_DEFAULT_ALL,
-            [('text/uri-list', 0, _DRAG_EXTERNAL_ID)], gtk.gdk.ACTION_COPY)
+            [('text/uri-list', 0, _DRAG_EXTERNAL_ID)],
+            gtk.gdk.ACTION_COPY | gtk.gdk.ACTION_MOVE)
         self._iconview.set_selection_mode(gtk.SELECTION_MULTIPLE)
         self.add(self._iconview)
 
@@ -949,7 +950,8 @@ class _AddBooksProgressDialog(gtk.Dialog):
             if library.backend.add_book(path, collection):
                 total_added += 1
                 number_label.set_text('%d' % total_added)
-            added_label.set_text(_("Adding '%s'...") % path)
+            added_label.set_text(_("Adding '%s'...") %
+                encoding.to_unicode(path))
             bar.set_fraction((i + 1) / total_paths)
             while gtk.events_pending():
                 gtk.main_iteration(False)
